#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################


from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('backend', '0001_initial'),
    ]

    operations = [
        migrations.RenameModel('QueueWorkerSlot', 'Slot'),
        migrations.RenameField(
            model_name='slot',
            old_name='nb_slots',
            new_name='quantity',
        ),
        migrations.AddField(
            model_name='slot',
            name='priority',
            field=models.PositiveIntegerField(default=0, help_text=b'Priority of these slots on the defined queue'),
        ),
        migrations.AlterUniqueTogether(
            name='slot',
            unique_together=set([('queue', 'worker')]),
        ),
        migrations.RenameField(
            model_name='queue',
            old_name='nb_cores_per_slot',
            new_name='cores_per_slot',
        ),
        migrations.AlterField(
            model_name='worker',
            name='active',
            field=models.BooleanField(default=False, help_text='If this worker is usable presently'),
        ),
        migrations.RenameField(
            model_name='worker',
            old_name='nb_cores',
            new_name='cores',
        ),
        migrations.AddField(
            model_name='worker',
            name='info',
            field=models.TextField(help_text=b'Informative message from the worker', null=True, blank=True),
        ),
        migrations.AddField(
            model_name='worker',
            name='memory',
            field=models.PositiveIntegerField(default=0, help_text=b'In megabytes'),
        ),
        migrations.AddField(
            model_name='worker',
            name='used_cores',
            field=models.PositiveIntegerField(default=0, help_text=b'In %'),
        ),
        migrations.AddField(
            model_name='worker',
            name='used_memory',
            field=models.PositiveIntegerField(default=0, help_text=b'In %'),
        ),
        migrations.AddField(
            model_name='worker',
            name='update',
            field=models.BooleanField(default=False, help_text='If this worker state must be updated at the next cycle'),
        ),
        migrations.AddField(
            model_name='worker',
            name='updated',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AlterField(
            model_name='queue',
            name='name',
            field=models.CharField(help_text=b'The name for this object (space-like characters will be automatically replaced by dashes)', unique=True, max_length=100),
        ),
        migrations.AlterField(
            model_name='queue',
            name='cores_per_slot',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterField(
            model_name='queue',
            name='max_slots_per_user',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterField(
            model_name='queue',
            name='memory_limit',
            field=models.PositiveIntegerField(help_text=b'In megabytes'),
        ),
        migrations.AlterField(
            model_name='queue',
            name='time_limit',
            field=models.PositiveIntegerField(help_text=b'In minutes'),
        ),
        migrations.AlterField(
            model_name='slot',
            name='quantity',
            field=models.PositiveIntegerField(help_text=b'Number of processing slots to dedicate in this worker for a given queue', verbose_name=b'Number of slots'),
        ),
        migrations.AlterField(
            model_name='worker',
            name='cores',
            field=models.PositiveIntegerField(),
        ),
        migrations.AlterField(
            model_name='environment',
            name='previous_version',
            field=models.ForeignKey(related_name='next_versions', on_delete=models.deletion.SET_NULL, blank=True, to='backend.Environment', null=True),
        ),
        migrations.CreateModel(
            name='Result',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('status', models.IntegerField()),
                ('stdout', models.TextField(null=True, blank=True)),
                ('stderr', models.TextField(null=True, blank=True)),
                ('usrerr', models.TextField(null=True, blank=True)),
                ('syserr', models.TextField(null=True, blank=True)),
                ('_stats', models.TextField(null=True, blank=True)),
                ('timed_out', models.BooleanField(default=False)),
                ('cancelled', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('status', models.CharField(default=b'N', max_length=1, choices=[(b'N', b'Queued'), (b'P', b'Processing'), (b'C', b'Completed'), (b'F', b'Failed'), (b'S', b'Skipped'), (b'L', b'Cancelled'), (b'K', b'Kill')])),
                ('runnable_date', models.DateTimeField(null=True, blank=True)),
                ('start_date', models.DateTimeField(null=True, blank=True)),
                ('end_date', models.DateTimeField(null=True, blank=True)),
                ('split_errors', models.PositiveIntegerField(default=0)),
                ('block', models.OneToOneField(related_name='job', on_delete=models.deletion.CASCADE, to='experiments.Block', null=True)),
                ('parent', models.OneToOneField(related_name='child', to='backend.Job', null=True, on_delete=models.deletion.SET_NULL)),
                ('result', models.OneToOneField(to='backend.Result', null=True, on_delete=models.deletion.CASCADE, related_name='job')),
            ],
        ),
        migrations.CreateModel(
            name='JobSplit',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('split_index', models.PositiveIntegerField()),
                ('start_index', models.PositiveIntegerField(null=True)),
                ('end_index', models.PositiveIntegerField(null=True)),
                ('status', models.CharField(default=b'N', max_length=1, choices=[(b'N', b'Queued'), (b'P', b'Processing'), (b'C', b'Completed'), (b'F', b'Failed'), (b'S', b'Skipped'), (b'L', b'Cancelled'), (b'K', b'Kill')])),
                ('start_date', models.DateTimeField(null=True)),
                ('end_date', models.DateTimeField(null=True)),
                ('process_id', models.PositiveIntegerField(null=True)),
                ('job', models.ForeignKey(related_name='splits', to='backend.Job', null=True)),
                ('worker', models.ForeignKey(related_name='splits', on_delete=models.deletion.SET_NULL, to='backend.Worker', null=True)),
                ('result', models.OneToOneField(to='backend.Result', related_name='split', null=True, on_delete=models.deletion.CASCADE)),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='jobsplit',
            unique_together=set([('job', 'split_index')]),
        ),
    ]
