#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from __future__ import unicode_literals

from django.db import migrations, models
import beat.web.code.models
import beat.web.databases.models
from django.conf import settings
import beat.web.common.models


class Migration(migrations.Migration):

    dependencies = [
        ('dataformats', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('team', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Database',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('sharing', models.CharField(default=b'P', max_length=1, choices=[(b'P', b'Private'), (b'S', b'Shared'), (b'A', b'Public'), (b'U', b'Usable')])),
                ('name', models.CharField(help_text=b'The name for this object (space-like characters will be automatically replaced by dashes)', max_length=200)),
                ('version', models.PositiveIntegerField(default=1, help_text=b'The version of this object (an integer starting from 1)')),
                ('short_description', models.CharField(default=b'', help_text=b'Describe the object succinctly (try to keep it under 80 characters)', max_length=100, blank=True)),
                ('creation_date', models.DateTimeField(auto_now_add=True, verbose_name=b'Creation date')),
                ('hash', models.CharField(help_text=b'Hashed value of the object contents (<a href="https://docs.python.org/2/library/hashlib.html">SHA256, hexadecimal digest</a>). This field is auto-generated and managed by the platform.', max_length=64, editable=False)),
                ('declaration_file', models.FileField(db_column=b'declaration', upload_to=beat.web.common.models.get_contribution_declaration_filename, storage=beat.web.databases.models.DatabaseStorage(), max_length=200, blank=True, null=True)),
                ('description_file', models.FileField(db_column=b'description', upload_to=beat.web.common.models.get_contribution_description_filename, storage=beat.web.databases.models.DatabaseStorage(), max_length=200, blank=True, null=True)),
                ('source_code_file', models.FileField(db_column=b'source_code', upload_to=beat.web.code.models.get_contribution_source_code_filename, storage=beat.web.databases.models.DatabaseStorage(), max_length=200, blank=True, null=True)),
                ('fork_of', models.ForeignKey(related_name='forks', blank=True, to='databases.Database', null=True)),
                ('previous_version', models.ForeignKey(related_name='next_versions', blank=True, to='databases.Database', null=True)),
                ('shared_with', models.ManyToManyField(related_name='shared_databases', to=settings.AUTH_USER_MODEL, blank=True)),
                ('shared_with_team', models.ManyToManyField(related_name='shared_databases', to='team.Team', blank=True)),
            ],
        ),
        migrations.CreateModel(
            name='DatabaseOutput',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=200)),
                ('dataformat', models.ForeignKey(related_name='database_outputs', to='dataformats.DataFormat')),
            ],
        ),
        migrations.CreateModel(
            name='DatabaseProtocol',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=200, blank=True)),
                ('database', models.ForeignKey(related_name='protocols', to='databases.Database')),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='DatabaseSet',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=200, blank=True)),
                ('protocol', models.ForeignKey(related_name='sets', to='databases.DatabaseProtocol')),
            ],
        ),
        migrations.CreateModel(
            name='DatabaseSetTemplate',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(unique=True, max_length=200)),
            ],
        ),
        migrations.AddField(
            model_name='databaseset',
            name='template',
            field=models.ForeignKey(related_name='sets', to='databases.DatabaseSetTemplate'),
        ),
        migrations.AddField(
            model_name='databaseoutput',
            name='template',
            field=models.ForeignKey(related_name='outputs', to='databases.DatabaseSetTemplate'),
        ),
        migrations.AlterUniqueTogether(
            name='databaseset',
            unique_together=set([('protocol', 'name', 'template')]),
        ),
        migrations.AlterUniqueTogether(
            name='databaseprotocol',
            unique_together=set([('database', 'name')]),
        ),
        migrations.AlterUniqueTogether(
            name='databaseoutput',
            unique_together=set([('template', 'name', 'dataformat')]),
        ),
        migrations.AlterUniqueTogether(
            name='database',
            unique_together=set([('name', 'version')]),
        ),
    ]
