/*
 * Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/
 * Contact: beat.support@idiap.ch
 * 
 * This file is part of the beat.web module of the BEAT platform.
 * 
 * Commercial License Usage
 * Licensees holding valid commercial BEAT licenses may use this file in
 * accordance with the terms contained in a written agreement between you
 * and Idiap. For further information contact tto@idiap.ch
 * 
 * Alternatively, this file may be used under the terms of the GNU Affero
 * Public License version 3 as published by the Free Software and appearing
 * in the file LICENSE.AGPL included in the packaging of this file.
 * The BEAT platform is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * You should have received a copy of the GNU Affero Public License along
 * with the BEAT platform. If not, see http://www.gnu.org/licenses/.
*/
/* beat.dataformats.models.js

   Declaration of the dataformats-related classes
*/


// Declaration of our namespaces
if (beat === undefined)
    var beat = {}

if (beat.dataformats === undefined)
    beat.dataformats = {}

if (beat.dataformats.models === undefined)
    beat.dataformats.models = {}


/******************************** CLASS: DataFormatList *********************************/

//----------------------------------------------------------------------------------------
// Constructor
//
// Allows to easily manipulate a list of data formats
//
// declaration: JSON declaration of the list, as returned by the Web API
//----------------------------------------------------------------------------------------
beat.dataformats.models.DataFormatList = function(declaration)
{
    // Attributes
    this.declaration = declaration;
    this.names       = new Array();

    // Initialisation
    for (var i = 0; i < declaration.length; ++i)
        this.names.push(declaration[i].name);
}


//----------------------------------------------------------------------------------------
// Retrieves the details about a data format
//----------------------------------------------------------------------------------------
beat.dataformats.models.DataFormatList.prototype.get = function(name)
{
    if (!name)
        return null;

    if (this.names.indexOf(name) == -1)
        return null;

    for (var i = 0; i < this.declaration.length; i++)
    {
        var details = this.declaration[i];

        if (details.name == name)
            return details;
    }

    return null;
}


//----------------------------------------------------------------------------------------
// Determine if two data formats are compatible
//----------------------------------------------------------------------------------------
beat.dataformats.models.DataFormatList.prototype.areCompatible = function(extension_name, base_name)
{
    if (extension_name === null)
        return true;

    if (base_name === null)
        return true;

    var extension = this.get(extension_name);
    if (extension == null)
        return false;

    if (this.names.indexOf(base_name) == -1)
        return false;

    while ((extension != null) && (extension.name != base_name))
        extension = this.get(extension.extend);

    return (extension != null);
}


//----------------------------------------------------------------------------------------
// Returns the distance between two formats, or -1 if they are not compatible
//----------------------------------------------------------------------------------------
beat.dataformats.models.DataFormatList.prototype.distance = function(extension_name, base_name)
{
    if (extension_name === null)
        return 0;

    if (base_name === null)
        return 0;

    var extension = this.get(extension_name);
    if (extension == null)
        return -1;

    if (this.names.indexOf(base_name) == -1)
        return -1;

    var distance = 0;
    while ((extension != null) && (extension.name != base_name))
    {
        extension = this.get(extension.extend);
        distance += 1;
    }

    if (extension != null)
        return distance;

    return -1;
}
