#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from ..common.api import ListContributionView
from .models import Plotter, PlotterParameter, DefaultPlotter
from .serializers import PlotterSerializer, PlotterParameterSerializer, DefaultPlotterSerializer
from django.db.models import Q

from rest_framework import generics
from rest_framework import views
from rest_framework import permissions
from rest_framework.response import Response
from rest_framework import status


class ListPlotterView(ListContributionView):
    """
    List all available plotters
    """
    model = Plotter
    serializer_class = PlotterSerializer


class ListFormatPlotterView(ListContributionView):
    """
    List all plotters corresponding to the given dataformat
    """
    model = Plotter
    serializer_class = PlotterSerializer

    def get_queryset(self):
        return self.model.objects.filter(
            dataformat__author__username = self.kwargs.get('author_name'),
            dataformat__name = self.kwargs.get('dataformat_name'),
            dataformat__version = self.kwargs.get('version'))

class ListPlotterParameterView(ListContributionView):
    """
    List all available plotters parameters
    """
    model = PlotterParameter
    serializer_class = PlotterParameterSerializer

    def get_queryset(self):
        username = self.kwargs.get('author_name')
        name = self.kwargs.get('dataformat_name')
        version = self.kwargs.get('version')
        if username and name and version:
            return self.model.objects.filter(
                dataformat__author__username = username,
                dataformat__name = name,
                dataformat__version = version)
        else:
            return self.model.objects.all()

class ListDefaultPlotterView(generics.ListAPIView):
    """
    List all available plotters parameters
    """
    model = DefaultPlotter
    serializer_class = DefaultPlotterSerializer
    def list(self, request):
        queryset = DefaultPlotter.objects.all()

        serializer = DefaultPlotterSerializer(queryset, many=True, context={'request': request})

        return Response(serializer.data)
