#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################


"""\
Processes one split.

Usage:
  %(prog)s [--settings=<file>] [--cpulimit=<file>] [-v ...] <execute> <split>
  %(prog)s (-h | --help)
  %(prog)s (-V | --version)

Arguments:


  <execute>  The path to the base execution program for running the user code
  <split>    The primary-key of the split to treat by this subprocess


Options:
  -h, --help                    Show this help message
  -V, --version                 Show program's version number
  -v, --verbose                 Increases the output verbosity level
  -S <file>, --settings=<file>  The module name to the Django settings file
                                [default: beat.web.settings.settings]
  -C <file>, --cpulimit=<file>  The path to the cpulimit program to use. If
                                not set, CPU limiting is not enforced.


Examples:

  To start the job split processing do the following:

    $ %(prog)s <path-to-execute> <split-id>

  You can optionally pass the ``-v`` flag to start the worker with the logging
  level set to ``INFO`` or ``-vv`` to set it to ``DEBUG``. By default, the
  logging level is set to ``WARNING`` if no ``-v`` flag is passed.

  You can optionally also set the path to the ``cpulimit`` program to use. If
  it is not set, then CPU limiting will not be enforced.

"""


import logging
logger = logging.getLogger('beat')


import os
import sys
import docopt


def main(user_input=None):

    arguments = docopt.docopt(
      __doc__ % dict(
        prog=os.path.basename(sys.argv[0]),
        ),
      )


    # Sets-up logging
    if arguments['--verbose'] == 1: logger.setLevel(logging.INFO)
    elif arguments['--verbose'] >= 2: logger.setLevel(logging.DEBUG)

    # Initializes the Django framework
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', arguments['--settings'])
    from django.conf import settings
    from django import setup
    setup()

    from beat.web.backend.schedule import process

    process(
        split_pk=int(arguments['<split>']),
        execute=arguments['<execute>'],
        cpulimit=arguments['--cpulimit'],
        )
