#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from __future__ import unicode_literals

from django.db import migrations, models
import datetime
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('experiments', '0001_initial'),
        ('algorithms', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('team', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Leaderboard',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('changed', models.DateTimeField(default=datetime.datetime.now)),
            ],
        ),
        migrations.CreateModel(
            name='Rank',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('order', models.PositiveIntegerField()),
                ('algorithm', models.ForeignKey(to='algorithms.Algorithm')),
                ('experiment', models.ForeignKey(to='experiments.Experiment')),
                ('leaderboard', models.ForeignKey(to='search.Leaderboard')),
                ('result', models.ManyToManyField(to='experiments.Result')),
            ],
        ),
        migrations.CreateModel(
            name='Search',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('sharing', models.CharField(default=b'P', max_length=1, choices=[(b'P', b'Private'), (b'S', b'Shared'), (b'A', b'Public'), (b'U', b'Usable')])),
                ('name', models.CharField(help_text=b'The name for this object (space-like characters will be automatically replaced by dashes)', max_length=200)),
                ('version', models.PositiveIntegerField(default=1, help_text=b'The version of this object (an integer starting from 1)')),
                ('short_description', models.CharField(default=b'', help_text=b'Describe the object succinctly (try to keep it under 80 characters)', max_length=100, blank=True)),
                ('creation_date', models.DateTimeField(auto_now_add=True, verbose_name=b'Creation date')),
                ('hash', models.CharField(help_text=b'Hashed value of the object contents (<a href="https://docs.python.org/2/library/hashlib.html">SHA256, hexadecimal digest</a>). This field is auto-generated and managed by the platform.', max_length=64, editable=False)),
                ('filters', models.TextField(default=b'', blank=True)),
                ('settings', models.TextField(default=b'', blank=True)),
                ('description', models.TextField(default=b'', help_text=b'Describe the object thoroughly using <a href="http://docutils.sourceforge.net/rst.html">reStructuredText mark-up</a><br/><i class="fa fa-thumbs-up"></i> The ruler at 80 columns indicate suggested <a href="https://en.wikipedia.org/wiki/POSIX">POSIX line breaks</a> (for readability).<br/><i class="fa fa-thumbs-up"></i> The editor will automatically enlarge to accomodate the entirety of your input<br/><i class="fa fa-thumbs-up"></i> Use <a href="http://codemirror.net/doc/manual.html#commands">keyboard shortcuts</a> for search/replace and faster editing. For example, use Ctrl-F (PC) or Cmd-F (Mac) to search through this box', blank=True)),
                ('author', models.ForeignKey(related_name='searchs', to=settings.AUTH_USER_MODEL)),
                ('fork_of', models.ForeignKey(related_name='forks', blank=True, to='search.Search', null=True)),
                ('previous_version', models.ForeignKey(related_name='next_versions', blank=True, to='search.Search', null=True)),
                ('shared_with', models.ManyToManyField(related_name='shared_searchs', to=settings.AUTH_USER_MODEL, blank=True)),
                ('shared_with_team', models.ManyToManyField(related_name='shared_searchs', to='team.Team', blank=True)),
            ],
            options={
                'verbose_name_plural': 'searches',
            },
        ),
        migrations.AddField(
            model_name='leaderboard',
            name='experiments',
            field=models.ManyToManyField(help_text=b'Experiments currently set on the leaderboard', related_name='leaderboards', through='search.Rank', to='experiments.Experiment', blank=True),
        ),
        migrations.AddField(
            model_name='leaderboard',
            name='notify',
            field=models.ManyToManyField(help_text=b'If set, and the leader board changes, an e-mail notification will be sent to people on this list, every time it changes.', to=settings.AUTH_USER_MODEL, blank=True),
        ),
        migrations.AddField(
            model_name='leaderboard',
            name='search',
            field=models.OneToOneField(related_name='leaderboard', to='search.Search'),
        ),
    ]
