/*
 * Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/
 * Contact: beat.support@idiap.ch
 * 
 * This file is part of the beat.web module of the BEAT platform.
 * 
 * Commercial License Usage
 * Licensees holding valid commercial BEAT licenses may use this file in
 * accordance with the terms contained in a written agreement between you
 * and Idiap. For further information contact tto@idiap.ch
 * 
 * Alternatively, this file may be used under the terms of the GNU Affero
 * Public License version 3 as published by the Free Software and appearing
 * in the file LICENSE.AGPL included in the packaging of this file.
 * The BEAT platform is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * You should have received a copy of the GNU Affero Public License along
 * with the BEAT platform. If not, see http://www.gnu.org/licenses/.
*/
/* beat.toolchains.dialogs.js

   Implementation of the toolchain-related dialogs
*/


// Declaration of our namespaces
if (beat === undefined)
    var beat = {}

if (beat.toolchains === undefined)
    beat.toolchains = {}

if (beat.toolchains.dialogs === undefined)
    beat.toolchains.dialogs = {}


/********************************** CLASS: BlockInfos ***********************************/

//----------------------------------------------------------------------------------------
// Constructor
//
// dialog_id: ID of the DOM element to use
//----------------------------------------------------------------------------------------
beat.toolchains.dialogs.ImportSettings = function(dialog_id, toolchain_url_prefix)
{
    var dialog = this;


    // Initialisations
    this.id                   = dialog_id;
    this.element              = $('#' + dialog_id)[0];
    this.toolchain_url_prefix = toolchain_url_prefix;
    this.toolchain            = null;

    this.onToolchainSelected = null;
    this.onCancel = null;


    // Create the dialog
    $('#' + this.id).dialog({
        autoOpen: false,
        resizable: false,
        width: Math.min($(window).width() * 0.6, 600),
        height: 300,
        modal: true,
        closeOnEscape: true,

        buttons: [
            // Import button
            {
                id: 'button-' + dialog_id + '-import',
                text: 'Import',
                click: function() {
                    var prefix = $('#' + dialog.id + ' #prefix')[0].value.trim().replace(/\W/g, '_');
                    var suffix = $('#' + dialog.id + ' #suffix')[0].value.trim().replace(/\W/g, '_');

                    if ((prefix.length > 0) || (suffix.length > 0))
                    {
                        var block_names = dialog.toolchain.components().map(function(x) { return x.name; });
                        for (var i = 0; i < block_names.length; ++i)
                        {
                            var new_name = block_names[i];

                            if (prefix.length > 0)
                            {
                                if (prefix[prefix.length - 1] != '_')
                                    prefix += '_';

                                new_name = prefix + new_name;
                            }

                            if (suffix.length > 0)
                            {
                                if (suffix[0] != '_')
                                    suffix = '_' + suffix;

                                new_name += suffix;
                            }

                            dialog.toolchain.renameComponent(block_names[i], new_name);
                        }
                    }

                    // Invoke the callback
                    if (dialog.onToolchainSelected)
                        dialog.onToolchainSelected(dialog.toolchain);

                    // Close the dialog
                    $(dialog.element).dialog("close");
                }
            },

            // Cancel button
            {
                id: 'button-' + dialog_id + '-cancel',
                text: 'Cancel',
                click: function() {
                    // Invoke the callback
                    if (dialog.onCancel)
                        dialog.onCancel();

                    $(dialog.element).dialog("close");
                }
            }
        ],
    });
}


//----------------------------------------------------------------------------------------
// Display the dialog
//----------------------------------------------------------------------------------------
beat.toolchains.dialogs.ImportSettings.prototype.display = function(toolchain_name)
{
    $('#' + this.id + ' div.progress').show();
    $('#' + this.id + ' div.settings').hide();

    $(this.element).dialog("open");

    var dialog = this;

    $.get(this.toolchain_url_prefix + toolchain_name + '/?fields=declaration', function(data) {
        dialog.toolchain = new beat.toolchains.models.Toolchain(data.declaration);

        $('#' + dialog.id + ' #infos').text('' + dialog.toolchain.nbDatasets() + ' datasets, ' +
                                            dialog.toolchain.nbBlocks() + ' blocks, ' +
                                            dialog.toolchain.nbAnalyzers() + ' analyzers'
        );

        $('#' + dialog.id + ' div.progress').hide();
        $('#' + dialog.id + ' div.settings').show();
    });
}


//----------------------------------------------------------------------------------------
// Hide the dialog
//----------------------------------------------------------------------------------------
beat.toolchains.dialogs.ImportSettings.prototype.hide = function()
{
    $('#' + this.id + ' #infos').text("");
    $('#' + this.id + ' #prefix')[0].value = '';
    $('#' + this.id + ' #suffix')[0].value = '';

    $(this.element).dialog("close");
}
