/*
 * Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/
 * Contact: beat.support@idiap.ch
 * 
 * This file is part of the beat.web module of the BEAT platform.
 * 
 * Commercial License Usage
 * Licensees holding valid commercial BEAT licenses may use this file in
 * accordance with the terms contained in a written agreement between you
 * and Idiap. For further information contact tto@idiap.ch
 * 
 * Alternatively, this file may be used under the terms of the GNU Affero
 * Public License version 3 as published by the Free Software and appearing
 * in the file LICENSE.AGPL included in the packaging of this file.
 * The BEAT platform is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * You should have received a copy of the GNU Affero Public License along
 * with the BEAT platform. If not, see http://www.gnu.org/licenses/.
*/
/* beat.ui.reportdialog.js

   Implementation of the 'reports' dialog
*/


// Declaration of our namespaces
if (beat === undefined)
    var beat = {}

if (beat.ui === undefined)
    beat.ui = {}

if (beat.ui.report === undefined)
    beat.ui.report = {}



beat.ui.report.add_experiments = function(dialog_id, received_data, experiments_list)
{
    // Create the dialog
    $('#' + dialog_id).dialog({
        autoOpen: false,
        resizable: false,
        width: Math.min($(window).width() * 0.6, 700),
        position: { my: "center", at: "center", of: window },
        modal: true,
        closeOnEscape: true,
        buttons: [
            {
                id: 'button-' + dialog_id + '-delete',
                text: 'Ok',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });
                    $("#report_add_experiments .warnings .experimentslist").empty();
                    $("#report_add_experiments .errors .errorslist").empty();
                    $('#' + dialog_id).dialog("close");
                }
            },
        ]
    });

    if (received_data)
    {
        if(experiments_list != undefined)
        {
            $("#report_add_experiments .errors").show();
            var items = [];
            var errors_length = 0;
            $.each( received_data, function( key, value ) {
                if(experiments_list.length != value.length)
                {
                    $("#report_add_experiments .warnings").show();
                    $("#report_add_experiments .warnings .experimentslist").append(experiments_list.length-value.length + "/" + experiments_list.length + " experiments to the report");
                }
                else
                {
                    $("#report_add_experiments .warnings").hide();
                }

                if(value.length  > 1)
                {
                    var allValues = '<ul>';
                    $.each( value, function( key2, value2 ) {
                       allValues += '<li>' + value2 + '</li>';
                    })
                    allValues += '</ul>';
                    items.push('<li>' + key + ": " + allValues + '</li>');
                }
                else
                {
                    items.push('<li>' + key + ": " + value + '</li>');
                }
            })
            $("#report_add_experiments .errors .errorslist").append( items.join('') );
        }
        else
        {
            var items = [];
            items.push('<li>' + received_data.responseText + '</li>');
            $("#report_add_experiments .warnings").hide();
            $("#report_add_experiments .errors .errorslist").append( items.join('') );
        }

    }
    else
    {
        $("#report_add_experiments .warnings").show();
        $("#report_add_experiments .warnings .experimentslist").append(experiments_list.length+ "/" + experiments_list.length + " experiments to the report");
        $("#report_add_experiments .errors").hide();

    }

    // Display the dialog
    $('#' + dialog_id).dialog("open");
}

beat.ui.report.lock_report = function(dialog_id, scope)
{
    var num_click = 0;
    // Create the dialog
    $('#' + dialog_id).dialog({
        autoOpen: false,
        resizable: false,
        width: Math.min($(window).width() * 0.6, 700),
        position: { my: "center", at: "center", of: window },
        modal: true,
        closeOnEscape: true,
        buttons: [
            {
                id: 'button-' + dialog_id + '-ok',
                text: 'Ok',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });

                    //$('#' + dialog_id).dialog("close");
                    if(num_click == 0)
                    {
                        num_click++;

                        scope.reportFactory.lockReport(scope.user, scope.report_id, scope.url_prefix)
                           .success(function (reportData)
                           {
                                $(".explanation_text").hide();
                                $("#report_lock .warnings").show();
                                $("#report_lock .errors").hide();
                                $("#button-report_lock-cancel").hide();
                           })
                           .error(function (error)
                           {
                                scope.status = 'Unable to lock report data: ' + error;
                                $(".explanation_text").hide();
                                $("#report_lock .warnings").hide();
                                $("#report_lock .errors").show();
                                if(error.detail != undefined)
                                    scope.status = 'Unable to lock report data: ' + error.detail;
                                $("#report_lock .errors .errorslist").append(scope.status);
                                $("#button-report_lock-cancel").hide();
                           });
                    }
                    else
                    {
                        $('#' + dialog_id).dialog("close");
                        $(".explanation_text").show();
                        $("#report_lock .warnings").hide();
                        $("#report_lock .errors").hide();
                        $("#report_lock .errors .errorslist").empty();
                        num_click = 0;
                        location.reload();
                    }

                }
            },
            {
                id: 'button-' + dialog_id + '-cancel',
                text: 'Cancel',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });
                    $('#' + dialog_id).dialog("close");
                }
            },
        ]
    });

    // Display the dialog
    $('#' + dialog_id).dialog("open");
}

beat.ui.report.publish_report = function(dialog_id, scope, algorithms_list)
{
    var num_click = 0;
    // Create the dialog
    $('#' + dialog_id).dialog({
        autoOpen: false,
        resizable: false,
        width: Math.min($(window).width() * 0.6, 700),
        position: { my: "center", at: "center", of: window },
        modal: true,
        closeOnEscape: true,
        buttons: [
            {
                id: 'button-' + dialog_id + '-ok',
                text: 'Ok',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });

                    //$('#' + dialog_id).dialog("close");
                    if(num_click == 0)
                    {
                        num_click++;

                        if(algorithms_list.length > 0)
                        {
                            var data = {
                                visible_algorithms: [],
                            };

                            var inputs = $('#' + dialog_id + ' div.algorithms ul.algorithmslist input');

                            for (var i = 0; i < inputs.length; ++i)
                            {
                                if (!inputs[i].checked)
                                    data.visible_algorithms.push(inputs[i].value);
                            }

                            var send_data = JSON.stringify(data);

                            scope.reportFactory.publishReport(scope.url_prefix, scope.user, scope.report_id, send_data)
                               .success(function (reportData)
                               {
                                    $(".explanation_text").hide();
                                    $("#report_publish .warnings").show();
                                    $("#report_publish .errors").hide();
                                    $("#button-report_publish-cancel").hide();
                               })
                               .error(function (error)
                               {
                                    scope.status = 'Unable to publish report data: ' + error;
                                    $(".explanation_text").hide();
                                    $("#report_publish .warnings").hide();
                                    $("#report_publish .errors").show();
                                    if(error.detail != undefined)
                                        scope.status = 'Unable to publish report data: ' + error.detail;
                                    $("#report_publish .errors .errorslist").append(scope.status);
                                    $("#button-report_publish-cancel").hide();
                               });

                        }
                        else
                        {
                            scope.reportFactory.publishReport(scope.url_prefix, scope.user, scope.report_id)
                               .success(function (reportData)
                               {
                                    $(".explanation_text").hide();
                                    $("#report_publish .warnings").show();
                                    $("#report_publish .errors").hide();
                                    $("#button-report_publish-cancel").hide();
                               })
                               .error(function (error)
                               {
                                    scope.status = 'Unable to publish report data: ' + error;
                                    $(".explanation_text").hide();
                                    $("#report_publish .warnings").hide();
                                    $("#report_publish .errors").show();
                                    if(error.detail != undefined)
                                        scope.status = 'Unable to publish report data: ' + error.detail;
                                    $("#report_publish .errors .errorslist").append(scope.status);
                                    $("#button-report_publish-cancel").hide();
                               });
                        }


                    }
                    else
                    {
                        $('#' + dialog_id).dialog("close");
                        $(".explanation_text").show();
                        $("#report_publish .warnings").hide();
                        $("#report_publish .errors").hide();
                        $("#report_publish .errors .errorslist").empty();
                        num_click = 0;
                        location.reload();
                    }
                }
            },
            {
                id: 'button-' + dialog_id + '-cancel',
                text: 'Cancel',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });
                    $('#' + dialog_id).dialog("close");
                }
            },
        ]
    });

    if(algorithms_list.length > 0 && num_click == 0)
    {
        // Initialise the dialog content
        $('#' + dialog_id + ' div.explanation_text .algorithms ul.algorithmslist').empty();


        // Populate the list of algorithms
        parent = $('#' + dialog_id + ' div.explanation_text .algorithms ul.algorithmslist')[0];

        for (var i = 0; i < algorithms_list.length; ++i)
        {
            var li = document.createElement('li');

            var input       = document.createElement('input');
            input.type      = 'checkbox';
            input.className = 'algorithm';
            input.value     = algorithms_list[i];
            input.checked   = true;

            li.appendChild(input);

            var a = document.createElement('a');
            a.href        = scope.url_prefix + '/algorithms/' + algorithms_list[i] + '/';
            a.target      = '_blank';
            a.textContent = algorithms_list[i];

            li.appendChild(a);

            parent.appendChild(li);
        }

        $('#' + dialog_id + ' div.explanation_text .algorithms').show();


    }

    // Display the dialog
    $('#' + dialog_id).dialog("open");
}

beat.ui.report.remove_experiment = function(dialog_id, experiment_id, scope)
{
    var num_click = 0;
    // Create the dialog
    $('#' + dialog_id).dialog({
        autoOpen: false,
        resizable: false,
        width: Math.min($(window).width() * 0.6, 700),
        position: { my: "center", at: "center", of: window },
        modal: true,
        closeOnEscape: true,
        buttons: [
            {
                id: 'button-' + dialog_id + '-ok',
                text: 'Ok',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });

                    //$('#' + dialog_id).dialog("close");
                    if(num_click == 0)
                    {
                        num_click++;

                        var data_to_send = {};
                        data_to_send['experiments'] = [experiment_id];
                        scope.reportFactory.removeExperiment(scope.user, scope.report_id, data_to_send, scope.url_prefix)
                           .success(function (reportData)
                           {
                                $(".explanation_text").hide();
                                $("#report_remove_experiment .warnings").show();
                                $("#report_remove_experiment .errors").hide();
                                $("#button-report_remove_experiment-cancel").hide();
                           })
                           .error(function (error)
                           {
                                scope.status = 'Unable to remove experiment from report: ' + error;
                                $(".explanation_text").hide();
                                $("#report_remove_experiment .warnings").hide();
                                $("#report_remove_experiment .errors").show();
                                if(error.detail != undefined)
                                    scope.status = 'Unable to remove experiment from report: ' + error.detail;
                                $("#report_remove_experiment .errors .errorslist").append(scope.status);
                                $("#button-report_remove_experiment-cancel").hide();
                           });
                    }
                    else
                    {
                        $('#' + dialog_id).dialog("close");
                        $(".explanation_text").show();
                        $("#report_remove_experiment .warnings").hide();
                        $("#report_remove_experiment .errors").hide();
                        $("#report_remove_experiment .errors .errorslist").empty();
                        num_click = 0;
                        location.reload();
                    }

                }
            },
            {
                id: 'button-' + dialog_id + '-cancel',
                text: 'Cancel',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });
                    $('#' + dialog_id).dialog("close");
                }
            },
        ]
    });

    // Display the dialog
    $('#' + dialog_id).dialog("open");
}

beat.ui.report.remove_item = function(dialog_id, elementToRemove, scope)
{
    var num_click = 0;
    // Create the dialog
    $('#' + dialog_id).dialog({
        autoOpen: false,
        resizable: false,
        width: Math.min($(window).width() * 0.6, 700),
        position: { my: "center", at: "center", of: window },
        modal: true,
        closeOnEscape: true,
        buttons: [
            {
                id: 'button-' + dialog_id + '-ok',
                text: 'Ok',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });

                    //$('#' + dialog_id).dialog("close");
                    if(num_click == 0)
                    {
                        num_click++;

                        if(elementToRemove.id.split("_")[0] == 'table')
                        {
                            delete scope.tables_details[elementToRemove.id];
                        }
                        else
                        {
                            delete scope.plots_details[elementToRemove.id];
                        }

                        var index = scope.report.orderedcontent.indexOf(elementToRemove.id);
                        if(index > -1)
                        {
                            scope.report.orderedcontent.splice(index, 1);
                        }

                        delete scope.report.content[elementToRemove.id];


                        $("#" + elementToRemove.id).remove();

                        $('#' + dialog_id).dialog("close");
                    }
                }
            },
            {
                id: 'button-' + dialog_id + '-cancel',
                text: 'Cancel',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });
                    $('#' + dialog_id).dialog("close");
                }
            },
        ]
    });

    // Display the dialog
    $('#' + dialog_id).dialog("open");
}

beat.ui.report.report_saved = function(dialog_id, scope)
{
    var num_click = 0;
    // Create the dialog
    $('#' + dialog_id).dialog({
        autoOpen: false,
        resizable: false,
        width: Math.min($(window).width() * 0.6, 700),
        position: { my: "center", at: "center", of: window },
        modal: true,
        closeOnEscape: true,
        buttons: [
            {
                id: 'button-' + dialog_id + '-ok',
                text: 'Ok',
                click: function() {
                    var data = {};
                    $.ajaxSetup({
                        beforeSend: function(xhr, settings) {
                            xhr.setRequestHeader('X-CSRFToken', $.cookie('csrftoken'));
                        }
                    });

                    //$('#' + dialog_id).dialog("close");
                    if(num_click == 0)
                    {
                        num_click++;
                        $(".explanation_text").hide();
                        $('#' + dialog_id).dialog("close");
                        $(".explanation_text").show();
                        num_click = 0;
                        location.reload();
                    }
                }
            },
        ]
    });

    // Display the dialog
    $('#' + dialog_id).dialog("open");
}
