#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from django.conf.urls import url, include
from django.conf import settings
from django.views.generic import TemplateView
from django.contrib.staticfiles.urls import staticfiles_urlpatterns

from .ui import urls as ui_urls
from .navigation import urls as navigation_urls

from urlparse import urlparse

from django.contrib import admin
admin.autodiscover()

# Views
unprefixed_patterns = ui_urls.urlpatterns
unprefixed_patterns += navigation_urls.urlpatterns

unprefixed_patterns += [

    url(r'^algorithms/',
      include('beat.web.algorithms.urls', namespace='algorithms'),
      ),

    url(r'^libraries/',
      include('beat.web.libraries.urls', namespace='libraries'),
      ),

    url(r'^attestations/',
      include('beat.web.attestations.urls', namespace='attestations'),
      ),

    url(r'^backend/',
      include('beat.web.backend.urls', namespace='backend'),
      ),

    url(r'^dataformats/',
      include('beat.web.dataformats.urls', namespace='dataformats'),
      ),

    url(r'^databases/',
      include('beat.web.databases.urls', namespace='databases'),
      ),

    url(r'^experiments/',
      include('beat.web.experiments.urls', namespace='experiments'),
      ),

    url(r'^search/',
      include('beat.web.search.urls', namespace='search'),
      ),

    url(r'^statistics/',
      include('beat.web.statistics.urls', namespace='statistics'),
      ),

    url(r'^toolchains/',
      include('beat.web.toolchains.urls', namespace='toolchains'),
      ),

    url(r'^teams/',
      include('beat.web.team.urls', namespace='teams'),
      ),

    url(r'^plotters/',
      include('beat.web.plotters.urls', namespace='plotters'),
      ),

    url(r'^reports/',
      include('beat.web.reports.urls', namespace='reports'),
      ),

    url(r'^accounts/',
        include('beat.web.accounts.urls', namespace='accounts'),
        ),

    url(r'^admin/', include(admin.site.urls)),

    url(r'^docs/',
      include('rest_framework_swagger.urls', namespace='docs'),
      ),

    url(r'^activity/',
        include('actstream.urls'),
        ),

    ]


# API
unprefixed_patterns += [

    url(r'^api/v1/teams/',
      include('beat.web.team.api_urls', namespace='api_teams'),
      ),

    url(r'^api/v1/algorithms/',
      include('beat.web.algorithms.api_urls', namespace='api_algorithms'),
      ),

    url(r'^api/v1/attestations/',
      include('beat.web.attestations.api_urls', namespace='api_attestations'),
      ),

    url(r'^api/v1/backend/',
      include('beat.web.backend.api_urls', namespace='api_backend'),
      ),

    url(r'^api/v1/databases/',
      include('beat.web.databases.api_urls', namespace='api_databases'),
      ),

    url(r'^api/v1/dataformats/',
      include('beat.web.dataformats.api_urls', namespace='api_dataformats'),
      ),

    url(r'^api/v1/experiments/',
      include('beat.web.experiments.api_urls', namespace='api_experiments'),
      ),

    url(r'^api/v1/libraries/',
      include('beat.web.libraries.api_urls', namespace='api_libraries'),
      ),

    url(r'^api/v1/search/',
      include('beat.web.search.api_urls', namespace='api_search'),
      ),

    url(r'^api/v1/toolchains/',
      include('beat.web.toolchains.api_urls', namespace='api_toolchains'),
      ),

    url(r'^api/v1/plotters/',
      include('beat.web.plotters.api_urls', namespace='api_plotters'),
      ),

    url(r'^api/v1/reports/',
        include('beat.web.reports.api_urls', namespace='api_reports'),
        ),

    ]


# Process an eventual prefix in the URLs
parsed_url = urlparse(settings.URL_PREFIX)
if (parsed_url.path != '') and (parsed_url.path != '/'):
    urlpatterns = [
        url(r'^%s/' % parsed_url.path[1:], include(unprefixed_patterns)),
    ]
else:
    urlpatterns = unprefixed_patterns

# Static files (only working during development, when settings.DEBUG is True)
urlpatterns += staticfiles_urlpatterns()
