#!/usr/bin/env python
# vim: set fileencoding=utf-8 :

###############################################################################
#                                                                             #
# Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.web module of the BEAT platform.              #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from django.conf import settings
from django.http import HttpResponse
from django.core.mail import send_mail
import traceback

import logging
logger = logging.getLogger(__name__)


#----------------------------------------------------------

def report_server_error(additional_content=None):
    try:
        subject = settings.EMAIL_SUBJECT_PREFIX + 'Internal server error'

        message = traceback.format_exc()

        if additional_content:
            message = additional_content + '\n\n' + message

        send_mail(subject, message, settings.DEFAULT_FROM_EMAIL,
                  map(lambda x: x[1], settings.ADMINS))
    except Exception:
        import traceback
        logger.warn("Could not send e-mail to system administrators about " \
            "`%s'. Exception caught: %s", subject, traceback.format_exc())

    return HttpResponse(status=500)

#----------------------------------------------------------

def send_email_to_administrators(title, content):
    try:
        subject = settings.EMAIL_SUBJECT_PREFIX + title

        send_mail(subject, content, settings.DEFAULT_FROM_EMAIL,
                  map(lambda x: x[1], settings.ADMINS))
    except Exception:
        import traceback
        logger.warn("Could not send e-mail to system administrators about " \
            "`%s'. Exception caught: %s", subject, traceback.format_exc())
